@@ -101,7 +101,7 @@ class Venue():
             try:
                 act = Act(self, a)
                 self.acts[a] = act
-            except ImportError:
+            except:
                 pass
 
 
